@@ -3,6 +3,7 @@ from PyQt5.Qt import *
 from PyQt5.uic import *
 from PyQt5.QtCore import *
 from PyQt5.QtWidgets import *
+#from downloader import *
 import sys
 import requests
 import os
@@ -23,6 +24,10 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.te = ''
         self.progressBar.setValue(0)
         self.pushButton_2.clicked.connect(self.fwa)
+
+        self.setWindowIcon(QIcon('icon.bmp'))
+        print(f'[{time.ctime()}][main/Info] icon loaded')
+
         try:
             self.load()
             print(f'[{time.ctime()}][main/Info] load settings.properties sucsess')
